# Counterintuitive behavior of pseudo-ranks - examples

########################################################

library(rankFD)


#########################################################

# TOC:
# (1) Code for reproducing the results from Sect. 3
# (2) Code for reproducing the results of the last paragraph of 
# Sect. 4


###############

# (1) settings for psi_1 - psi_4 (using the notation from the supplement;
# in the manuscript, this corresponds to the example provided in
# Section 3)

mu1 = 4; mu2 = 2; mu4 = 0 ;
sig1 = sqrt(0.25); sig2 = sqrt(0.25); sig4 = sqrt(0.25);
set.seed(0)
n = 500;
y1 = rnorm(n, mu1, sig1)
y2 = rnorm(n/2, mu2, sig2)
y3 = rnorm(n/2, mu2, sig2)
y4 = rnorm(n, mu4, sig4)

# 4 groups
group.ind.4 = c(rep(1,n),rep(2,n/2),rep(3,n/2),rep(4,n))
dfr.4 = data.frame(Group = factor(group.ind.4), Outcome = c(y1,y2,y3,y4))
# relative effects (pseudo-rank-based)
rel.eff.4 = rankFD(Outcome ~ Group, data = dfr.4, effect = "unweighted")$Descriptive$pd
rel.eff.4
Diff4 = rel.eff.4[1]-rel.eff.4[4]

# 3 groups (i.e., merging groups 2 and 3)
group.ind.3 = group.ind.4
group.ind.3[group.ind.3 == 3] = 2
dfr.3 = data.frame(Group = factor(group.ind.3), Outcome = c(y1,y2,y3,y4))
# relative effects (ps-rank-based)
rel.eff.3 = rankFD(Outcome ~ Group, data = dfr.3, effect = "unweighted")$Descriptive$pd
rel.eff.3
Diff3 = rel.eff.3[1]-rel.eff.3[3]

# more groups: split F_2/F_3 into 10 groups of size n/10 = 50 each
# and compare the 12-group-comparison results with the 
# 3-group setting, then

group.ind.12 = group.ind.4
group.ind.12[group.ind.12 == 4] = 12
group.ind.12[group.ind.12 %in% c(2,3)] = c(sapply(2:11, function(k){rep(k,n/10)}))
table(group.ind.12)

dfr.12 = data.frame(Group = factor(group.ind.12), Outcome = c(y1,y2,y3,y4))
# relative effects (ps-rank-based)
rel.eff.12 = rankFD(Outcome ~ Group, data = dfr.12, effect = "unweighted")$Descriptive$pd
rel.eff.12
Diff12 = rel.eff.12[1]-rel.eff.12[12]

# compare
data.frame(N.groups = c(3,4,12), Diff.1.4 = c(Diff3,Diff4,Diff12))








###############







# (2) settings for psi_1 - psi_4, but with sigma_i^2 = 2 
# (this corresponds to the example provided in the last paragraph of 
# Sect. 4)

mu1 = 4; mu2 = 2; mu4 = 0 ;
sig1 = sqrt(2); sig2 = sqrt(2); sig4 = sqrt(2);
set.seed(0)
n = 500;
y1 = rnorm(n, mu1, sig1)
y2 = rnorm(n/2, mu2, sig2)
y3 = rnorm(n/2, mu2, sig2)
y4 = rnorm(n, mu4, sig4)

# 4 groups
group.ind.4 = c(rep(1,n),rep(2,n/2),rep(3,n/2),rep(4,n))
dfr.4 = data.frame(Group = factor(group.ind.4), Outcome = c(y1,y2,y3,y4))
# relative effects (ps-rank-based)
rel.eff.4 = rankFD(Outcome ~ Group, data = dfr.4, effect = "unweighted")$Descriptive$pd
rel.eff.4
Diff4 = rel.eff.4[1]-rel.eff.4[4]

# 3 groups
group.ind.3 = group.ind.4
group.ind.3[group.ind.3 == 3] = 2
dfr.3 = data.frame(Group = factor(group.ind.3), Outcome = c(y1,y2,y3,y4))
# relative effects (ps-rank-based)
rel.eff.3 = rankFD(Outcome ~ Group, data = dfr.3, effect = "unweighted")$Descriptive$pd
rel.eff.3
Diff3 = rel.eff.3[1]-rel.eff.3[3]

# more groups: split F_2/F_3 into 10 groups of size n/10 = 50 each

group.ind.12 = group.ind.4
group.ind.12[group.ind.12 == 4] = 12
group.ind.12[group.ind.12 %in% c(2,3)] = c(sapply(2:11, function(k){rep(k,n/10)}))
table(group.ind.12)

dfr.12 = data.frame(Group = factor(group.ind.12), Outcome = c(y1,y2,y3,y4))
# relative effects (ps-rank-based)
rel.eff.12 = rankFD(Outcome ~ Group, data = dfr.12, effect = "unweighted")$Descriptive$pd
rel.eff.12
Diff12 = rel.eff.12[1]-rel.eff.12[12]

# compare
data.frame(N.groups = c(3,4,12), Diff.1.4 = c(Diff3,Diff4,Diff12))






##################################



 