# Real-life data example on ranks vs. pseudo-ranks

library(rankFD)
library(pseudorank)
library(ggplot2)

# data import
dat.ps = read.delim("Data_psranks_new.txt", header = TRUE, dec = ",")

dat.ps = na.omit(dat.ps)

#################################################

# Code for reproducing the estimates of the relative effects reported
# in Section 4

# rank- and pseudo-rank-based relative effects (with rankFD)

# rank-based relative effects
rankFD(Gesamtcomfort_Summenscore_T1 ~ Stadt,
       data = dat.ps, effect = "weighted",
       hypothesis = "H0F")$Descriptive

# pseudo-rank based counterpart
rankFD(Gesamtcomfort_Summenscore_T1 ~ Stadt,
       data = dat.ps, effect = "unweighted",
       hypothesis = "H0F")$Descriptive

#####

# merge the data from centers in 
# Baden-Wurttemberg and Bavaria, respectively

dat.new = dat.ps
dat.new$Stadt = as.character(dat.new$Stadt)
dat.new$Stadt[dat.new$Stadt%in% c("Freiburg",
                                  "Tbingen","Kork")] = "Baden-Wurttemberg"
dat.new$Stadt[dat.new$Stadt%in% c("Mnchen",
                                  "Vogtareuth","Erlangen")] = "Bavaria"
dat.new$Stadt = factor(dat.new$Stadt,
                       levels = c("Innsbruck","Linz","Salzburg","Wien",
                                  "Baden-Wurttemberg","Bavaria"))

# now, calculate the rank- and pseudo-rank-based relative effects
# again

# rank-based
rankFD(Gesamtcomfort_Summenscore_T1 ~ Stadt,
       data = dat.new, effect = "weighted",
       hypothesis = "H0F")$Descriptive

# pseudo-rank-based
rankFD(Gesamtcomfort_Summenscore_T1 ~ Stadt,
       data = dat.new, effect = "unweighted",
       hypothesis = "H0F")$Descriptive


##############################################

# Code to reproduce the boxplot presented in Section 4

pl = ggplot(aes(x = Stadt, y = Gesamtcomfort_Summenscore_T1),
            data = dat.ps) + geom_boxplot(colour = c("blue","blue","red","blue","red","blue","red","blue","blue","red"))
pl = pl + xlab("Centre") + ylab("Total comfort score")
pl = pl + theme(axis.text.x = element_text(size = 11),
                axis.text.y = element_text(size = 11))
pl
ggsave("comfortCentres.eps",device = "eps",
       height = 10, width = 20, units = "cm",
       dpi = 600)
